@@ -1,7 +1,7 @@
 package Bencher::Scenario::TreeObject::Build;
 
-our $DATE = '2016-03-31'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-04-14'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -42,7 +42,7 @@ Bencher::Scenario::TreeObject::Build - Benchmark tree building using Tree::Creat
 
 =head1 VERSION
 
-This document describes version 0.03 of Bencher::Scenario::TreeObject::Build (from Perl distribution Bencher-Scenarios-TreeObject), released on 2016-03-31.
+This document describes version 0.04 of Bencher::Scenario::TreeObject::Build (from Perl distribution Bencher-Scenarios-TreeObject), released on 2016-04-14.
 
 =head1 SYNOPSIS
 
@@ -60,13 +60,15 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Tree::Object::Array> 0.06
+L<Tree::Object::Array> 0.07
 
-L<Tree::Object::Array::Glob> 0.06
+L<Tree::Object::Array::Glob> 0.07
 
-L<Tree::Object::Hash> 0.06
+L<Tree::Object::Hash> 0.07
 
-L<Tree::Object::Hash::ChildrenAsList> 0.06
+L<Tree::Object::Hash::ChildrenAsList> 0.07
+
+L<Tree::Object::InsideOut> 0.07
 
 L<Tree::ObjectXS::Array> 0.02
 
@@ -108,6 +110,14 @@ Code template:
 
 
 
+=item * Tree::Object::InsideOut (perl_code)
+
+Code template:
+
+ Tree::Create::Size::create_tree(height => <height>, num_children => <num_children>, class => 'Tree::Object::InsideOut')
+
+
+
 =item * Tree::ObjectXS::Array (perl_code)
 
 Code template:
@@ -154,19 +164,20 @@ A tree with height=6 and 5 children per non-leaf nodes, nodes=1 + 5 + 25 + 125 +
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with C<< bencher -m TreeObject::Build --include-datasets 'small1 (31 nodes)' >>:
 
  +------------------------------------+-----------+-----------+------------+------------------+---------+---------+
  | participant                        | rate (/s) | time (μs) | vs_slowest | result_size (kB) | errors  | samples |
  +------------------------------------+-----------+-----------+------------+------------------+---------+---------+
- | Tree::Object::Hash::ChildrenAsList | 8.3e+03   | 1.2e+02   | 1          | 9.7              | 2.1e-07 | 20      |
- | Tree::Object::Hash                 | 8.4e+03   | 1.2e+02   | 1          | 9.7              | 6.2e-07 | 21      |
- | Tree::Object::Array::Glob          | 9.2e+03   | 1.1e+02   | 1.1        | 3.8              | 2.4e-07 | 25      |
- | Tree::Object::Array                | 1e+04     | 1e+02     | 1.2        | 6.1              | 1.3e-07 | 20      |
- | Tree::ObjectXS::Hash               | 1.2e+04   | 84        | 1.4        | 7.9              | 1.3e-07 | 20      |
- | Tree::ObjectXS::Array              | 1.2e+04   | 81        | 1.5        | 6.1              | 1.1e-07 | 20      |
+ | Tree::Object::InsideOut            | 1.1e+04   | 93        | 1          | 0.14             | 3.2e-07 | 20      |
+ | Tree::Object::Hash::ChildrenAsList | 1.6e+04   | 62        | 1.5        | 9.7              | 1e-07   | 21      |
+ | Tree::Object::Hash                 | 1.7e+04   | 60        | 1.5        | 9.7              | 8e-08   | 20      |
+ | Tree::Object::Array::Glob          | 1.8e+04   | 56        | 1.7        | 3.8              | 1.1e-07 | 20      |
+ | Tree::Object::Array                | 2e+04     | 50        | 1.9        | 6.1              | 1.6e-07 | 21      |
+ | Tree::ObjectXS::Hash               | 2.4e+04   | 42        | 2.2        | 7.9              | 4.9e-08 | 24      |
+ | Tree::ObjectXS::Array              | 2.4e+04   | 41        | 2.3        | 6.1              | 5.3e-08 | 20      |
  +------------------------------------+-----------+-----------+------------+------------------+---------+---------+
 
 
@@ -175,12 +186,13 @@ Benchmark with C<< bencher -m TreeObject::Build --include-datasets 'medium1 (195
  +------------------------------------+-----------+-----------+------------+------------------+---------+---------+
  | participant                        | rate (/s) | time (ms) | vs_slowest | result_size (MB) | errors  | samples |
  +------------------------------------+-----------+-----------+------------+------------------+---------+---------+
- | Tree::Object::Hash::ChildrenAsList | 15        | 65        | 1          | 5.8              | 9.1e-05 | 20      |
- | Tree::Object::Hash                 | 16        | 64        | 1          | 5.8              | 7.8e-05 | 20      |
- | Tree::Object::Array::Glob          | 18.1      | 55.3      | 1.18       | 2.38             | 4.6e-05 | 20      |
- | Tree::Object::Array                | 20        | 50        | 1.3        | 3.2              | 9.6e-05 | 20      |
- | Tree::ObjectXS::Hash               | 23        | 43        | 1.5        | 4.1              | 6.7e-05 | 20      |
- | Tree::ObjectXS::Array              | 24        | 41        | 1.6        | 3.2              | 7.5e-05 | 20      |
+ | Tree::Object::InsideOut            | 18        | 57        | 1          | 0.00014          | 0.00012 | 20      |
+ | Tree::Object::Hash::ChildrenAsList | 30        | 33        | 1.7        | 5.8              | 3.7e-05 | 20      |
+ | Tree::Object::Hash                 | 30.9      | 32.4      | 1.76       | 5.81             | 8.7e-06 | 21      |
+ | Tree::Object::Array::Glob          | 35.1      | 28.5      | 2          | 2.38             | 1.7e-05 | 21      |
+ | Tree::Object::Array                | 39.7      | 25.2      | 2.26       | 3.16             | 7.2e-06 | 21      |
+ | Tree::ObjectXS::Hash               | 46.7      | 21.4      | 2.66       | 4.14             | 9.9e-06 | 20      |
+ | Tree::ObjectXS::Array              | 48        | 20.8      | 2.73       | 3.16             | 4.8e-06 | 21      |
  +------------------------------------+-----------+-----------+------------+------------------+---------+---------+
 
 =head1 DESCRIPTION
